@@ -1189,11 +1189,13 @@ END
    ($stdout,$stderr)=$handle->cmd("make install",'__display__');
    ($stdout,$stderr)=$handle->cwd("..");
    ($stdout,$stderr)=$handle->cmd("wget -qO- http://memcached.org/");
-   $stdout=~/^.*?Tar.Gz Download.*?href=["](.*?)["].*$/;
+   $stdout=~/^.*?Tar.Gz Download.*?href=["](.*?)["].*$/s;
    my $mc_rel=$1;
    ($stdout,$stderr)=$handle->cmd(
       "wget --random-wait --progress=dot ".$mc_rel,'__display__');
    $mc_rel=~s/^.*\/(.*.tar.gz)$/$1/;
+   ($stdout,$stderr)=$handle->cmd("tar xvf $mc_rel",'__display__');
+   $mc_rel=~s/.tar.gz$//;
    ($stdout,$stderr)=$handle->cwd($mc_rel);
    ($stdout,$stderr)=$handle->cmd("./configure",'__display__'); 
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i 's/ -Werror//' Makefile");
